.. _spkg_sirocco:

sirocco: Compute topologically certified root continuation of bivariate polynomials
===================================================================================

Description
-----------

sirocco is a library to compute topologically certified root
continuation of bivariate polynomials.

License
-------

GPLv3+


Upstream Contact
----------------

Miguel Marco (mmarco@unizar.es)

https://github.com/miguelmarco/SIROCCO2


Type
----

optional


Dependencies
------------

- :ref:`spkg_mpfr`

Version Information
-------------------

package-version.txt::

    2.1.1

See https://repology.org/project/sirocco/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sirocco

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S sirocco

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install sirocco

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install sirocco sirocco-devel

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-sirocco

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install sirocco-devel


If the system package is installed, ``./configure`` will check if it can be used.
